/*
 * The FreeBSD Copyright
 * Copyright 1994-2008 The FreeBSD Project. All rights reserved.
 * Copyright (C) 2013-2023 Philip Helger philip[at]helger[dot]com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE FREEBSD PROJECT ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FREEBSD PROJECT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of the FreeBSD Project.
 */
package com.helger.as2lib.util;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;

import org.junit.Test;

/**
 * Test class for class {@link AS2HttpHelper}.
 *
 * @author Philip Helger
 */
public final class AS2HttpHelperTest
{
  @Test
  public void testParseContentType ()
  {
    assertNull (AS2HttpHelper.parseContentType (null));
    assertNull (AS2HttpHelper.parseContentType (""));
    assertNull (AS2HttpHelper.parseContentType ("    "));
    assertNull (AS2HttpHelper.parseContentType ("abc"));
    assertNull (AS2HttpHelper.parseContentType ("abc/"));
    assertNotNull (AS2HttpHelper.parseContentType ("abc/def"));
    assertNotNull (AS2HttpHelper.parseContentType ("abc/def; a=b"));
    assertNotNull (AS2HttpHelper.parseContentType ("    abc/def   ;    a   =   b   "));
    assertNotNull (AS2HttpHelper.parseContentType ("abc/def; a=b; c=d"));
    assertNotNull (AS2HttpHelper.parseContentType ("  abc/def  ;  a  =  b  ;  c  =  d  "));
  }

  @Test
  public void testGetCleanContentType ()
  {
    assertNull (AS2HttpHelper.getCleanContentType (null));
    assertNull (AS2HttpHelper.getCleanContentType (""));
    assertNull (AS2HttpHelper.getCleanContentType ("    "));
    assertNull (AS2HttpHelper.getCleanContentType ("abc"));
    assertNull (AS2HttpHelper.getCleanContentType ("abc/"));
    assertEquals ("abc/def", AS2HttpHelper.getCleanContentType ("abc/def"));
    assertEquals ("abc/def; a=b", AS2HttpHelper.getCleanContentType ("abc/def; a=b"));
    assertEquals ("abc/def; a=b", AS2HttpHelper.getCleanContentType ("    abc/def   ;    a   =   b   "));
    assertEquals ("abc/def; a=b; c=d", AS2HttpHelper.getCleanContentType ("abc/def; a=b; c=d"));
    assertEquals ("abc/def; a=b; c=d", AS2HttpHelper.getCleanContentType ("  abc/def  ;  a  =  b  ;  c  =  d  "));
  }
}
